
set scripts_board $BOARDNAME
set current_board_parts [get_board_parts]

if { [string first $scripts_board $current_board_parts] == -1 } {
   puts ""
   puts "ERROR: Please install Trenz Electronic Board Part Files!"
   return 1
}

file delete -force .srcs
file delete -force .Xil

#
# STEP#0: define output directory area.
#
set outputDir ./out/$PRODID
file mkdir $outputDir


# STEP#1: setup design sources and constraints
#
#read_vhdl -library work [ glob ./src/*.vhd ]         
read_xdc [ glob ../xdc/bitgen_common.xdc ]
read_xdc [ glob ./src/constraints/*.xdc ]


# Set project properties
set obj [current_project]
set_property "default_lib" "xil_defaultlib" $obj
set_property "part" $PARTNAME $obj
set_property "simulator_language" "Mixed" $obj
set_property "target_language" "VHDL" $obj
set_property "board" $BOARDNAME $obj


#set ip repository path
##set_property IP_REPO_PATHS ./ip_rep [current_fileset ]
##update_ip_catalog

# create the BD-Design
create_bd_design "$BDNAME"
source ./src/ipi/$PROJNAME\_bd.tcl
#update_compile_order -fileset sources_1
#update_compile_order -fileset sim_1
#save_bd_design

generate_target all [get_files  ./.srcs/sources_1/bd/$BDNAME/$BDNAME.bd]

#make_wrapper -files [get_files ./.srcs/sources_1/bd/$BDNAME/$BDNAME.bd] -top
add_files -norecurse ./.srcs/sources_1/bd/$BDNAME/hdl/$BDNAME\_wrapper.vhd

set fsboot_elf ../../common/sw/minlinux/fs-boot.elf
add_files -norecurse "$fsboot_elf"
set_property SCOPED_TO_REF $BDNAME [get_files -all -of_objects [get_fileset sources_1] "$fsboot_elf"]
set_property SCOPED_TO_CELLS { sys_microblaze } [get_files -all -of_objects [get_fileset sources_1] "$fsboot_elf"]
add_files -fileset sim_1 -norecurse "$fsboot_elf"
set_property SCOPED_TO_REF $BDNAME [get_files -all -of_objects [get_fileset sim_1] "$fsboot_elf"]
set_property SCOPED_TO_CELLS { sys_microblaze } [get_files -all -of_objects [get_fileset sim_1] "$fsboot_elf"]


# STEP#2: run synthesis, report utilization and timing estimates, write checkpoint design
#
synth_design -top $BDNAME\_wrapper -part $PARTNAME -flatten rebuilt -directive AreaOptimizedHigh   

##write_checkpoint -force $outputDir/post_synth
##report_timing_summary -file $outputDir/post_synth_timing_summary.rpt
##report_power -file $outputDir/post_synth_power.rpt

# STEP#3: run placement and logic optimzation, report utilization and timing estimates, write checkpoint design
#
opt_design
place_design
phys_opt_design
##write_checkpoint -force $outputDir/post_place
##report_timing_summary -file $outputDir/post_place_timing_summary.rpt

# STEP#4: run router, report actual utilization and timing, write checkpoint design, run drc, write verilog and xdc out
#
route_design
##write_checkpoint -force $outputDir/post_route
report_timing_summary -file $outputDir/post_route_timing_summary.rpt
##report_timing -sort_by group -max_paths 100 -path_type summary -file $outputDir/post_route_timing.rpt
##report_clock_utilization -file $outputDir/clock_util.rpt
report_utilization -file $outputDir/post_route_util.rpt
##report_power -file $outputDir/post_route_power.rpt
##report_drc -file $outputDir/post_imp_drc.rpt
##write_verilog -force $outputDir/bft_impl_netlist.v
##write_xdc -no_fixed_only -force $outputDir/bft_impl.xdc


# STEP#5: generate a bitstream
# 
write_bitstream -force $outputDir/$PROJNAME.bit
write_cfgmem -format MCS -force -interface SPIx4 -size 32 -loadbit "up 0x0 $outputDir/$PROJNAME.bit" -loaddata "up 0x400000 ../../common/sw/minlinux/512M-eth/u-boot-s.bin up 0x480000 ../../common/sw/minlinux/512M-eth/image.ub" -file "$outputDir/$PROJNAME.mcs"
report_io -force -file $outputDir/$PROJNAME\_io_report.txt -format text
close_project
