----------------------------------------------------------------------------------
--! @file
--! @brief	Blink DONE pin (LED) using onchip oscillator as clock source
--! @author	Antti Lukats 
-- 
-- Create Date:    10:59:23 12/17/2013 
-- Design Name: 
-- Module Name:    top - Behavioral 
-- Project Name: 
-- Target Devices: 
-- Tool versions: 
-- Description: 
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------

--! Use standard library
library IEEE;
--! Use logic elements
	use IEEE.STD_LOGIC_1164.ALL;
	use IEEE.STD_LOGIC_ARITH.ALL;
	use IEEE.STD_LOGIC_UNSIGNED.ALL;

--! Use Xilinx libraries
library UNISIM;
	use UNISIM.VComponents.all;

entity blinky_onchip_done is Port ( 
           dummy   : in  STD_LOGIC --! Dummy port to make sure the design is not optimzed away
	   );
end blinky_onchip_done;

architecture Behavioral of blinky_onchip_done is

signal LED_i: std_logic;

signal eos: std_logic;
signal cnt: std_logic_vector(31 downto 0);
signal clk: std_logic;

begin
--	LED_i <= '1' when eos='0' else not cnt(25);
	LED_i <= cnt(25);
	
process(clk)
begin
	if (rising_edge(clk)) then
		cnt <= cnt + X"00000001";
	end if;
end process;

   STARTUPE2_inst : STARTUPE2
   generic map (
      PROG_USR => "FALSE",  -- Activate program event security feature. Requires encrypted bitstreams.
      SIM_CCLK_FREQ => 0.0  -- Set the Configuration Clock Frequency(ns) for simulation.
   )
   port map (
      CFGCLK 	=> open,         -- 1-bit output: Configuration main clock output
      CFGMCLK 	=> clk,        -- 1-bit output: Configuration internal oscillator clock output
      EOS 	=> open,            -- 1-bit output: Active high output signal indicating the End Of Startup.
      PREQ 	=> open,           -- 1-bit output: PROGRAM request to fabric output
      CLK 	=> '0',             -- 1-bit input: User start-up clock input
      GSR 	=> '0',             -- 1-bit input: Global Set/Reset input (GSR cannot be used for the port name)
      GTS 	=> '0',             -- 1-bit input: Global 3-state input (GTS cannot be used for the port name)
      KEYCLEARB => '0' ,      -- 1-bit input: Clear AES Decrypter Key input from Battery-Backed RAM (BBRAM)
      PACK 	=> '1',            -- 1-bit input: PROGRAM acknowledge input
      USRCCLKO 	=> '1',        -- 1-bit input: User CCLK input
      USRCCLKTS => '1',       -- 1-bit input: User CCLK 3-state enable input
      USRDONEO 	=> LED_i,    -- 1-bit input: User DONE pin output control
      USRDONETS => '0'        -- 1-bit input: User DONE 3-state enable output
   );


end Behavioral;

